#
# spec file for package xkbutils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xkbutils
Version:        1.0.6
Release:        1.5
Summary:        Collection of small utilities utilizing the X11 XKeyboard extension
License:        MIT
Group:          System/X11/Utilities
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(inputproto)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
BuildRequires:  pkgconfig(xt)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
xkbutils is a collection of small utilities utilizing the XKeyboard
(XKB) extension to the X11 protocol.

It includes:
 xkbbell  - generate XKB bell events
 xkbvleds - display the state of LEDs on an XKB keyboard in a window
 xkbwatch - reports changes in the XKB keyboard state

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README.md
%{_bindir}/xkbbell
%{_bindir}/xkbvleds
%{_bindir}/xkbwatch
%{_mandir}/man1/xkbbell.1%{?ext_man}
%{_mandir}/man1/xkbvleds.1%{?ext_man}
%{_mandir}/man1/xkbwatch.1%{?ext_man}

%changelog
* Sun Feb  4 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.6
  * This release includes minor cleanups, including a fix for an
    issue that prevented building with gcc 14 betas.
* Tue Jul 12 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.5:
  * XkbQueryExtension returns a Bool, don't use > 0 to check it
  * Remove unused uStrCasePrefix fallback for strncasecmp
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * gitlab CI: add a basic build test
  * Build xz tarballs instead of bzip2
  * Use _CONST_X_STRING to make libXt declare String as const char *
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
* Tue Feb 26 2013 zaitor@opensuse.org
- Update to version 1.0.4:
  + Declare bit to shift as unsigned to clear compiler warning.
  + Add -version flags to all three commands.
  + Combine usage message strings/calls.
  + Delete unused macros from utils.h.
  + Remove unused u*alloc functions from utils.c.
  + Remove unused uStringDup function.
  + Make configure actually check for strcasecmp.
  + Remove unused debug & function tracing infrastructure from
    utils.c.
  + Mark uFatalError as _X_NORETURN.
  + Add printf attributes to utils.c printing functions.
  + Declare utils.c functions as taking const char * arguments.
  + Remove unused streq() macro.
  + Remove unused #ifdef notyet typedef.
  + Remove CVS version tags.
  + Convert to X.Org standard coding style.
  + Fix typo in SetValues which could fail to detect a change if
    only width/height changed.
  + config:
  - Add missing AC_CONFIG_SRCDIR.
  - Replace deprecated AM_CONFIG_HEADER with AC_CONFIG_HEADERS.
  - Move man pages into their own directory.
  + man: Remove trailing spaces and tabs.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xkbutils from xorg-x11. Initial version: 1.0.3.
